Class: Aws::CloudHSM::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::CloudHSM::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-cloudhsm/client.rb,
sig/client.rbs
Overview
An API client for CloudHSM. To construct a client, you need to configure a :region and :credentials.
client = Aws::CloudHSM::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _AddTagsToResourceResponseSuccess, _CreateHapgResponseSuccess, _CreateHsmResponseSuccess, _CreateLunaClientResponseSuccess, _DeleteHapgResponseSuccess, _DeleteHsmResponseSuccess, _DeleteLunaClientResponseSuccess, _DescribeHapgResponseSuccess, _DescribeHsmResponseSuccess, _DescribeLunaClientResponseSuccess, _GetConfigResponseSuccess, _ListAvailableZonesResponseSuccess, _ListHapgsResponseSuccess, _ListHsmsResponseSuccess, _ListLunaClientsResponseSuccess, _ListTagsForResourceResponseSuccess, _ModifyHapgResponseSuccess, _ModifyHsmResponseSuccess, _ModifyLunaClientResponseSuccess, _RemoveTagsFromResourceResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#add_tags_to_resource(params = {}) ⇒ Types::AddTagsToResourceResponse
This is documentation for AWS CloudHSM Classic.
-
#create_hapg(params = {}) ⇒ Types::CreateHapgResponse
This is documentation for AWS CloudHSM Classic.
-
#create_hsm(params = {}) ⇒ Types::CreateHsmResponse
This is documentation for AWS CloudHSM Classic.
-
#create_luna_client(params = {}) ⇒ Types::CreateLunaClientResponse
This is documentation for AWS CloudHSM Classic.
-
#delete_hapg(params = {}) ⇒ Types::DeleteHapgResponse
This is documentation for AWS CloudHSM Classic.
-
#delete_hsm(params = {}) ⇒ Types::DeleteHsmResponse
This is documentation for AWS CloudHSM Classic.
-
#delete_luna_client(params = {}) ⇒ Types::DeleteLunaClientResponse
This is documentation for AWS CloudHSM Classic.
-
#describe_hapg(params = {}) ⇒ Types::DescribeHapgResponse
This is documentation for AWS CloudHSM Classic.
-
#describe_hsm(params = {}) ⇒ Types::DescribeHsmResponse
This is documentation for AWS CloudHSM Classic.
-
#describe_luna_client(params = {}) ⇒ Types::DescribeLunaClientResponse
This is documentation for AWS CloudHSM Classic.
-
#get_config(params = {}) ⇒ Types::GetConfigResponse
This is documentation for AWS CloudHSM Classic.
-
#list_available_zones(params = {}) ⇒ Types::ListAvailableZonesResponse
This is documentation for AWS CloudHSM Classic.
-
#list_hapgs(params = {}) ⇒ Types::ListHapgsResponse
This is documentation for AWS CloudHSM Classic.
-
#list_hsms(params = {}) ⇒ Types::ListHsmsResponse
This is documentation for AWS CloudHSM Classic.
-
#list_luna_clients(params = {}) ⇒ Types::ListLunaClientsResponse
This is documentation for AWS CloudHSM Classic.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This is documentation for AWS CloudHSM Classic.
-
#modify_hapg(params = {}) ⇒ Types::ModifyHapgResponse
This is documentation for AWS CloudHSM Classic.
-
#modify_hsm(params = {}) ⇒ Types::ModifyHsmResponse
This is documentation for AWS CloudHSM Classic.
-
#modify_luna_client(params = {}) ⇒ Types::ModifyLunaClientResponse
This is documentation for AWS CloudHSM Classic.
-
#remove_tags_from_resource(params = {}) ⇒ Types::RemoveTagsFromResourceResponse
This is documentation for AWS CloudHSM Classic.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
478 479 480 |
# File 'lib/aws-sdk-cloudhsm/client.rb', line 478 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1681 1682 1683 |
# File 'lib/aws-sdk-cloudhsm/client.rb', line 1681 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1684 1685 1686 |
# File 'lib/aws-sdk-cloudhsm/client.rb', line 1684 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#add_tags_to_resource(params = {}) ⇒ Types::AddTagsToResourceResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Adds or overwrites one or more tags for the specified AWS CloudHSM resource.
Each tag consists of a key and a value. Tag keys must be unique to each resource.
87 |
# File 'sig/client.rbs', line 87
def add_tags_to_resource: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1654 1655 1656 1657 1658 1659 1660 1661 1662 1663 1664 1665 1666 1667 1668 1669 1670 |
# File 'lib/aws-sdk-cloudhsm/client.rb', line 1654 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::CloudHSM') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-cloudhsm' context[:gem_version] = '1.88.0' Seahorse::Client::Request.new(handlers, context) end |
#create_hapg(params = {}) ⇒ Types::CreateHapgResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Creates a high-availability partition group. A high-availability partition group is a group of partitions that spans multiple physical HSMs.
103 |
# File 'sig/client.rbs', line 103
def create_hapg: (
|
#create_hsm(params = {}) ⇒ Types::CreateHsmResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Creates an uninitialized HSM instance.
There is an upfront fee charged for each HSM instance that you create
with the CreateHsm operation. If you accidentally provision an HSM
and want to request a refund, delete the instance using the DeleteHsm
operation, go to the AWS Support Center, create a new case, and
select Account and Billing Support.
It can take up to 20 minutes to create and provision an HSM. You can
monitor the status of the HSM with the DescribeHsm operation. The HSM
is ready to be initialized when the status changes to RUNNING.
113 |
# File 'sig/client.rbs', line 113
def create_hsm: (
|
#create_luna_client(params = {}) ⇒ Types::CreateLunaClientResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Creates an HSM client.
130 |
# File 'sig/client.rbs', line 130
def create_luna_client: (
|
#delete_hapg(params = {}) ⇒ Types::DeleteHapgResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Deletes a high-availability partition group.
141 |
# File 'sig/client.rbs', line 141
def delete_hapg: (
|
#delete_hsm(params = {}) ⇒ Types::DeleteHsmResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Deletes an HSM. After completion, this operation cannot be undone and your key material cannot be recovered.
151 |
# File 'sig/client.rbs', line 151
def delete_hsm: (
|
#delete_luna_client(params = {}) ⇒ Types::DeleteLunaClientResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Deletes a client.
161 |
# File 'sig/client.rbs', line 161
def delete_luna_client: (
|
#describe_hapg(params = {}) ⇒ Types::DescribeHapgResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Retrieves information about a high-availability partition group.
179 |
# File 'sig/client.rbs', line 179
def describe_hapg: (
|
#describe_hsm(params = {}) ⇒ Types::DescribeHsmResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Retrieves information about an HSM. You can identify the HSM by its ARN or its serial number.
209 |
# File 'sig/client.rbs', line 209
def describe_hsm: (
|
#describe_luna_client(params = {}) ⇒ Types::DescribeLunaClientResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Retrieves information about an HSM client.
224 |
# File 'sig/client.rbs', line 224
def describe_luna_client: (
|
#get_config(params = {}) ⇒ Types::GetConfigResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Gets the configuration files necessary to connect to all high availability partition groups the client is associated with.
237 |
# File 'sig/client.rbs', line 237
def get_config: (
|
#list_available_zones(params = {}) ⇒ Types::ListAvailableZonesResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Lists the Availability Zones that have available AWS CloudHSM capacity.
249 |
# File 'sig/client.rbs', line 249
def list_available_zones: (
|
#list_hapgs(params = {}) ⇒ Types::ListHapgsResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Lists the high-availability partition groups for the account.
This operation supports pagination with the use of the NextToken
member. If more results are available, the NextToken member of the
response contains a token that you pass in the next call to
ListHapgs to retrieve the next set of items.
259 |
# File 'sig/client.rbs', line 259
def list_hapgs: (
|
#list_hsms(params = {}) ⇒ Types::ListHsmsResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Retrieves the identifiers of all of the HSMs provisioned for the current customer.
This operation supports pagination with the use of the NextToken
member. If more results are available, the NextToken member of the
response contains a token that you pass in the next call to ListHsms
to retrieve the next set of items.
270 |
# File 'sig/client.rbs', line 270
def list_hsms: (
|
#list_luna_clients(params = {}) ⇒ Types::ListLunaClientsResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Lists all of the clients.
This operation supports pagination with the use of the NextToken
member. If more results are available, the NextToken member of the
response contains a token that you pass in the next call to
ListLunaClients to retrieve the next set of items.
281 |
# File 'sig/client.rbs', line 281
def list_luna_clients: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Returns a list of all tags for the specified AWS CloudHSM resource.
291 |
# File 'sig/client.rbs', line 291
def list_tags_for_resource: (
|
#modify_hapg(params = {}) ⇒ Types::ModifyHapgResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Modifies an existing high-availability partition group.
301 |
# File 'sig/client.rbs', line 301
def modify_hapg: (
|
#modify_hsm(params = {}) ⇒ Types::ModifyHsmResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Modifies an HSM.
This operation can result in the HSM being offline for up to 15 minutes while the AWS CloudHSM service is reconfigured. If you are modifying a production HSM, you should ensure that your AWS CloudHSM service is configured for high availability, and consider executing this operation during a maintenance window.
313 |
# File 'sig/client.rbs', line 313
def modify_hsm: (
|
#modify_luna_client(params = {}) ⇒ Types::ModifyLunaClientResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Modifies the certificate used by the client.
This action can potentially start a workflow to install the new certificate on the client's HSMs.
328 |
# File 'sig/client.rbs', line 328
def modify_luna_client: (
|
#remove_tags_from_resource(params = {}) ⇒ Types::RemoveTagsFromResourceResponse
This is documentation for AWS CloudHSM Classic. For more information, see AWS CloudHSM Classic FAQs, the AWS CloudHSM Classic User Guide, and the AWS CloudHSM Classic API Reference.
For information about the current version of AWS CloudHSM, see AWS CloudHSM, the AWS CloudHSM User Guide, and the AWS CloudHSM API Reference.
Removes one or more tags from the specified AWS CloudHSM resource.
To remove a tag, specify only the tag key to remove (not the value). To overwrite the value for an existing tag, use AddTagsToResource.
339 |
# File 'sig/client.rbs', line 339
def remove_tags_from_resource: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1674 1675 1676 |
# File 'lib/aws-sdk-cloudhsm/client.rb', line 1674 def waiter_names [] end |